@@ -24,7 +24,7 @@ from macrometa_source_snowflake.sync_strategies.sample_data import fetch_samples
 import macrometa_source_snowflake.sync_strategies.common as common
 import macrometa_source_snowflake.sync_strategies.full_table as full_table
 import macrometa_source_snowflake.sync_strategies.incremental as incremental
-from macrometa_source_snowflake.connection import SnowflakeConnection
+from macrometa_source_snowflake.connection import SnowflakeConnection, create_private_key_file, delete_private_key_file
 
 LOGGER = singer.get_logger('macrometa_source_snowflake')
 
@@ -503,23 +503,28 @@ def do_sync(snowflake_conn, config, catalog, state, replication_method):
 
 def main_impl():
     args = utils.parse_args(REQUIRED_CONFIG_KEYS)
-
-    snowflake_conn = SnowflakeConnection(args.config)
-    replication_method = args.config.get('replication_method')
-    if args.discover:
-        do_discover(snowflake_conn, args.config)
-    elif args.catalog:
-        state = args.state or {}
-        do_sync(snowflake_conn, args.config,
-                args.catalog, state, replication_method)
-    elif args.properties:
-        catalog = Catalog.from_dict(args.properties)
-        state = args.state or {}
-        do_sync(snowflake_conn, args.config,
-                catalog, state, replication_method)
-    else:
-        LOGGER.info('No properties were selected')
-
+    config = args.config
+    snowflake_conn = SnowflakeConnection(config)
+    replication_method = config.get('replication_method')
+    try:
+        config = create_private_key_file(config)
+        if args.discover:
+            do_discover(snowflake_conn, config)
+        elif args.catalog:
+            state = args.state or {}
+            do_sync(snowflake_conn, config,
+                    args.catalog, state, replication_method)
+        elif args.properties:
+            catalog = Catalog.from_dict(args.properties)
+            state = args.state or {}
+            do_sync(snowflake_conn, config,
+                    catalog, state, replication_method)
+        else:
+            LOGGER.info('No properties were selected')
+    except Exception as e:
+        delete_private_key_file(config)
+        raise e
+    delete_private_key_file(config)
 
 class SnowflakeSourceConnector(C8Connector):
     """SnowflakeSourceConnector's C8Connector impl."""
@@ -555,14 +560,18 @@ class SnowflakeSourceConnector(C8Connector):
         config = self.get_config(integration)
         snowflake_conn = SnowflakeConnection(config)
         try:
+            config = create_private_key_file(config)
             do_discover(snowflake_conn, config)
         except Exception as e:
+            delete_private_key_file(config)
             raise e
+        delete_private_key_file(config)
 
     def samples(self, integration: dict) -> list[Sample]:
         """Fetch sample data using the provided configurations."""
         config = self.get_config(integration)
         try:
+            config = create_private_key_file(config)
             snowflake_conn = SnowflakeConnection(config)
             catalog = discover_catalog(snowflake_conn, config)
             results = []
@@ -596,13 +605,16 @@ class SnowflakeSourceConnector(C8Connector):
                 )
         except Exception as e:
             LOGGER.info('Exception raised: %s', e)
+            delete_private_key_file(config)
             raise e
+        delete_private_key_file(config)
         return results
 
     def schemas(self, integration: dict) -> list[C8Schema]:
         """Get supported schemas using the given configurations."""
         config = self.get_config(integration)
         try:
+            config = create_private_key_file(config)
             snowflake_conn = SnowflakeConnection(config)
             catalog = discover_catalog(snowflake_conn, config)
             results = []
@@ -630,7 +642,9 @@ class SnowflakeSourceConnector(C8Connector):
                 results.append(C8Schema(stream.stream, s_attribs))
         except Exception as e:
             LOGGER.info('Exception raised: %s', e)
+            delete_private_key_file(config)
             raise e
+        delete_private_key_file(config)
         return results
 
     def reserved_keys(self) -> list[str]:
@@ -662,7 +676,7 @@ class SnowflakeSourceConnector(C8Connector):
             ConfigProperty('user', 'Username', ConfigAttributeType.STRING, True, False,
                            description='Snowflake username.',
                            placeholder_value='my_user'),
-            ConfigProperty('password', 'Password', ConfigAttributeType.STRING, True, False,
+            ConfigProperty('password', 'Password', ConfigAttributeType.STRING, False, False,
                            description='Snowflake password.',
                            placeholder_value='my_password'),
             ConfigProperty('warehouse', 'Warehouse', ConfigAttributeType.STRING, True, False,
@@ -686,7 +700,7 @@ class SnowflakeSourceConnector(C8Connector):
                            description='Snowflake role to use.',
                            placeholder_value='my_role'),
             ConfigProperty('private_key_path', 'Private Key', ConfigAttributeType.STRING, False, False,
-                           description='A private key used for authenticating using Key Pair authentication instead of user/pass.',
+                           description='A private key used for authenticating using Key Pair authentication instead of user/pass. At the moment, only PEM format is supported.',
                            placeholder_value='my_private_key'),
             ConfigProperty('private_key_passphrase', 'Private Key Passphrase', ConfigAttributeType.STRING, False, False,
                            description='The private key passphrase used for authenticating using Key Pair authentication instead of user/pass.',
