@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
+import uuid
 from typing import Union, List, Dict
+from pathlib import Path
 
 import singer
 import sys
@@ -39,6 +41,52 @@ def validate_config(config):
 
     return errors
 
+# PRIVATE KEY PATH
+def create_private_key_file(config: Dict) -> Dict:
+    path_uuid = uuid.uuid4().hex
+    try:
+        if config.get('private_key_path'):
+            path = f"/opt/snowflake/{path_uuid}/rsa_key.p8"
+            private_key = Path(path)
+            private_key.parent.mkdir(exist_ok=True, parents=True)
+            private_key.write_text(create_private_key_string(config['private_key_path']))
+            config['private_key_path'] = path
+            LOGGER.info(f"Private key file created at: {path}")
+
+    except Exception as e:
+        LOGGER.warn(f'Failed to create private key: /opt/snowflake/{path_uuid}/rsa_key.p8')
+
+    return config
+
+def delete_private_key_file(config: Dict) -> None:
+    try:
+        private_key = None
+        if config.get('private_key_path'):
+            path = config['private_key_path']
+            private_key = Path(path)
+            config['private_key_path'] = private_key.read_text()
+            private_key.unlink()
+            LOGGER.info(f"Private key file deleted from: {path}")
+
+        if private_key is not None:
+            private_key.parent.rmdir()
+    except Exception as e:
+        LOGGER.warn(f"Failed to delete private key file: {e}")
+
+def create_private_key_string(private_key_string: str) -> str:
+    private_key_list = []
+    split_string = private_key_string.split("-----")
+    if len(split_string) < 4:
+        raise Exception("Invalid PEM format for private key.")
+    for i in range(len(split_string)):
+        if ((i % 2) == 1):
+            private_key_list.extend(("-----", split_string[i], "-----"))
+        else:
+            private_key_list.append(split_string[i].replace(' ', '\n'))
+
+    return ''.join(private_key_list)
+
+
 
 class SnowflakeConnection:
     """Class to manage connection to snowflake data warehouse"""
