@@ -10,7 +10,7 @@ import singer.metrics as metrics
 from singer import metadata
 from singer import utils
 
-LOGGER = singer.get_logger('tap_snowflake')
+LOGGER = singer.get_logger('macrometa_source_snowflake')
 
 
 def escape(string):
@@ -53,13 +53,6 @@ def property_is_selected(stream, property_name):
         True)
 
 
-def get_is_view(catalog_entry):
-    """Detect if stream is a view"""
-    md_map = metadata.to_map(catalog_entry.metadata)
-
-    return md_map.get((), {}).get('is-view')
-
-
 def get_database_name(catalog_entry):
     """Get database name from catalog"""
     md_map = metadata.to_map(catalog_entry.metadata)
@@ -79,14 +72,7 @@ def get_key_properties(catalog_entry):
     catalog_metadata = metadata.to_map(catalog_entry.metadata)
     stream_metadata = catalog_metadata.get((), {})
 
-    is_view = get_is_view(catalog_entry)
-
-    if is_view:
-        key_properties = stream_metadata.get('view-key-properties', [])
-    else:
-        key_properties = stream_metadata.get('table-key-properties', [])
-
-    return key_properties
+    return stream_metadata.get('table-key-properties', [])
 
 
 def generate_select_sql(catalog_entry, columns):
@@ -207,7 +193,8 @@ def sync_query(cursor, catalog_entry, state, select_sql, columns, stream_version
 
             md_map = metadata.to_map(catalog_entry.metadata)
             stream_metadata = md_map.get((), {})
-            replication_method = stream_metadata.get('replication-method', replication_method)
+            replication_method = stream_metadata.get(
+                'replication-method', replication_method)
 
             if replication_method == 'FULL_TABLE':
                 key_properties = get_key_properties(catalog_entry)
